@@ -2,11 +2,15 @@
 NULL
 
 #' @name as.seasonal
-#' @author Lucas Venezian Povoa \email{lucasvenez@@gmail.com} 
 #' @aliases as.precintcon.seasonal as.seasonal 
-#' @title Convert a precipitation serie to an seasonal serie 
+#' @author Lucas Venezian Povoa \email{lucasvenez@@gmail.com} 
+#' 
+#' @title Converting to seasonal precipitation serie
 #' @description Converts a daily or monthly precipitation serie 
-#' to a seasonal serie. 
+#' to a seasonal serie according to meteorological seasons.
+#' @details If the serie has no a month of a season, it is waived in convertion, e.g., 
+#' if a serie has January and February of 1975, but no December of 1974, the first two months are
+#' removed of the resulting serie because the season that depends all of them is not complete.
 #' @usage as.seasonal(object) 
 #' @param object a precintcon.daily, or precintcon.monthly object or 
 #' a data.frame containing 33 or 3 columns.
@@ -29,6 +33,4 @@ NULL
 #' as.seasonal(daily)
 #' @keywords seasonal precipitation
 #' @export 
-as.seasonal <- function(object) {
-   return(as.precintcon.seasonal(object))  
-}
\ No newline at end of file
+as.seasonal <- function(object) as.precintcon.seasonal(object)
\ No newline at end of file
