@@ -5,7 +5,7 @@ NULL
 #' @author Lucas Venezian Povoa \email{lucasvenez@@gmail.com} 
 #' @aliases precintcon.stat.analysis stat 
 #' @title Basic statistics for precipitation datasets. 
-#' @description Perform the calculation of basic statistics of precipitation datasets. 
+#' @description Calculates of basic statistics of precipitation datasets. 
 #' @usage stat(\dots) 
 #' @param \dots a set of daily or monthly precipitation serie.
 #' @return A data.frame (precintcon.stat) containing the following variables:
@@ -32,6 +32,4 @@ NULL
 #' stat(monthly)
 #' @keywords summary precipitation 
 #' @export
-stat <- function(...) {
-   return(precintcon.stat.analysis(...))
-}
\ No newline at end of file
+stat <- function(...) precintcon.stat.analysis(..., args = as.character(match.call()[1:length(list(...))+1]))
\ No newline at end of file
